diff dvdnav.h @ 95:e7ebabe059b9 src

Start to get dvd mrl working in xine.
author jcdutton
date Mon, 16 Sep 2002 16:54:41 +0000
parents df9712507b30
children 457f35f43ba6
line wrap: on
line diff
--- a/dvdnav.h	Mon Sep 16 16:27:18 2002 +0000
+++ b/dvdnav.h	Mon Sep 16 16:54:41 2002 +0000
@@ -275,9 +275,10 @@
  * Returns the number of programs within the current title.
  * 
  * \param self Pointer to dvdnav_t associated with this operation.
  * \param programs Pointer to int to receive number of programs.
  */
-dvdnav_status_t dvdnav_get_number_of_programs(dvdnav_t *self, int *programs);
+dvdnav_status_t dvdnav_get_number_of_parts(dvdnav_t *self, int title, int *parts);
 
 /**
  * If we are currently in a still-frame this function skips it (or attempts to).
@@ -275,9 +275,10 @@
  * 
  * \param self Pointer to dvdnav_t associated with this operation.
- * \param programs Pointer to int to receive number of programs.
+ * \param titles int to select title.
+ * \param parts Pointer to int to receive number of parts.
  */